[![Build Status](https://travis-ci.org/AckslD/QuAlg.svg?branch=master)](https://travis-ci.org/AckslD/QuAlg)

QuAlg (0.0.1)
=====================================================

Welcome to QuAlg's README.

Documentation
-------------
Full documentation can be found [here](https://acksld.github.io/qualg/).
The best way to get started is to have a look at the [quickstart-guide](https://acksld.github.io/qualg/quickstart.html).
The actual jupyter notebook of the quickstart-guide can be found [here](https://github.com/AckslD/QuAlg/blob/master/docs/quickstart.ipynb).

Installation
------------
To install the package do:
```bash
make install
```

To verify the installation do:
```
make verify
```
